class FatalProspectorException(Exception):

    """
    Exception used to indicate an internal prospector problem.
    Problems in prospector itself should raise this to notify
    the user directly. Errors in dependent tools should be
    caught and the user notified elegantly.

    """

    # (see also the --die-on-tool-error flag)

    def __init__(self, message):
        self.message = message



from abc import ABC, abstractmethod

__all__ = ("Formatter",)


class Formatter(ABC):
    def __init__(self, summary, messages, profile):
        self.summary = summary
        self.messages = messages
        self.profile = profile

    @abstractmethod
    def render(self, summary=True, messages=True, profile=False):
        raise NotImplementedError
